@@ -7,6 +7,7 @@
 
 package PDL::VectorValued;
 use strict;
+use warnings;
 
 ##======================================================================
 ## Export hacks
@@ -14,20 +15,70 @@ use PDL;
 use PDL::Exporter;
 use PDL::VectorValued::Utils;
 our @ISA = qw(PDL::Exporter);
-our @EXPORT_OK =
-  (
-   (@PDL::VectorValued::Utils::EXPORT_OK), ##-- inherited
-   qw(vv_uniqvec),
-   qw(rleND rldND),
-   qw(vv_indx),
-  );
+
+our (@EXPORT_OK);
+BEGIN {
+  ##--------------------------------------------------------------------
+  ## Conditional bindings for PDL > v2.079
+  ##  + see https://github.com/moocow-the-bovine/PDL-VectorValued/issues/5
+
+  ## @VV_SYMBOLS : exportable symbols (vv_FOO)
+  my @VV_SYMBOLS =
+    (
+     (@PDL::VectorValued::Utils::EXPORT_OK), ##-- inherited
+     qw(vv_uniqvec),
+     qw(vv_rleND vv_rldND),
+     qw(vv_indx),
+    );
+
+  # %VV_IMPORT: import these from PDL core if available (PDL > v2.079)
+  my %VV_IMPORT = (
+		   vv_rlevec => {vv=>'rlevec', p=>PDL->can('rlevec')},
+		   vv_rldvec => {vv=>'rldvec', p=>PDL->can('rldvec')},
+		   vv_rleseq => {vv=>'rleseq', p=>PDL->can('rleseq')},
+		   vv_rldseq => {vv=>'rldseq', p=>PDL->can('rldseq')},
+		   vv_enumvec => {vv=>'enumvec', p=>PDL->can('enumvec')},
+		   vv_enumvecg => {vv=>'enumvecg', p=>PDL->can('enumvecg')},
+		   vv_vsearchvec => {vv=>'vsearchvec', p=>PDL->can('vsearchvec')},
+		   vv_cmpvec => {vv=>'cmpvec', p=>PDL->can('cmpvec')},
+		   vv_union => {vv=>'vv_union', p=>PDL->can('unionvec')},
+		   vv_intersect => {vv=>'vv_intersect', p=>PDL->can('intersectvec')},
+		   vv_setdiff => {vv=>'vv_setdiff', p=>PDL->can('setdiffvec')},
+		   v_union => {vv=>'v_union', p=>PDL->can('union_sorted')},
+		   v_intersect => {vv=>'v_intersect', p=>PDL->can('intersect_sorted')},
+		   v_setdiff => {vv=>'v_setdiff', p=>PDL->can('setdiff_sorted')},
+		   vv_rleND => {vv=>'rleND', p=>PDL->can('rleND')},
+		   vv_rldND => {vv=>'rldND', p=>PDL->can('rldND')},
+		   #vv_indx => {vv=>'vv_indx', p=>PDL->can('indx')}, # DEBUG
+		  );
+
+
+  @EXPORT_OK = @VV_SYMBOLS;
+  foreach my $vv_sym (@VV_SYMBOLS) {
+    no strict 'refs';
+    if ($VV_IMPORT{$vv_sym} && defined($VV_IMPORT{$vv_sym}{p})) {
+      # function lives in PDL core: import it here, and clobber $vv_sym here (but not in VV::Utils)
+      no warnings 'redefine';
+      *$vv_sym = *{$VV_IMPORT{$vv_sym}{vv}} = $VV_IMPORT{$vv_sym}{p};
+    }
+    elsif ($VV_IMPORT{$vv_sym}) {
+      # $sym is defined here as "vv_$sym" : bind it here & in PDL namespace
+      my $sym = $VV_IMPORT{$vv_sym}{vv};
+      ${PDL::}{$sym} = *$sym = *$vv_sym;
+
+      # ... and make it exportable
+      push(@EXPORT_OK, $sym);
+    }
+  }
+}
+
 our %EXPORT_TAGS =
   (
    Func => [@EXPORT_OK],               ##-- respect PDL conventions (hopefully)
   );
 
 ## VERSION was formerly set by PDL::VectorValued::Version, now use perl-reversion from Perl::Version instead
-our $VERSION = '1.0.15';
+our $VERSION = '1.0.21';
 
 ##======================================================================
 ## pod: header
@@ -58,6 +109,58 @@ functions to higher-order PDLs which treat vectors as "data values".
 
 =cut
 
+
+##======================================================================
+## pod: Aliases
+=pod
+
+=head1 ALIASES
+
+To facilitate incorporation of selected vector-valued functions into
+the PDL core, the PDL:PP-, XS-, C-, and perl-level functions defined by
+this module in the C<PDL::VectorValued::Utils> package namespace
+all carry a C<vv_> prefix as of PDL::VectorValued v1.0.19
+Prior to v1.0.19, many of these functions (e.g. C<cmpvec()>)
+were defined by this module without a C<vv_> prefix.
+
+For PDL::VectorValued E<gt>= v1.0.19 and PDL E<gt> v2.079, most vector-valued
+functions are expected to be defined in the PDL core.  For such "moving" functions
+C<FUNC>, the PDL core implementations will be imported into the C<PDL::VectorValued>
+namespace as both C<FUNC> and C<vv_FUNC>, clobbering any local implementation
+from the C<PDL::VectorValued::Utils> namespace.  Local implementations
+C<vv_FUNC> which were previously defined and exported as C<FUNC>
+or for which no binding for C<*PDL::FUNC> exists will be bound to
+both C<*PDL::VectorValued::FUNC> and C<*PDL::FUNC>, and exported by default,
+for backwards-compatibility.
+
+Functions expected to move to the PDL core are:
+
+
+=over 4
+
+=item *
+
+New code should use C<FUNC()> or C<PDL::FUNC()>.
+
+=item *
+
+Backwards-compatible code can use C<FUNC()> or C<PDL::VectorValued::FUNC()>.
+
+=item *
+
+Direct use of C<PDL::VectorValued::Utils::vv_FUNC()> is deprecated.
+
+=item *
+
+Direct use of C<PDL::VectorValued::Utils::FUNC()> is likely broken as of
+PDL::VectorValued v1.0.19.
+
+
+=back
+
+=cut
+
+
 ##======================================================================
 ## pod: Functions
 =pod
@@ -120,7 +223,7 @@ The following functions generalize the builtin PDL functions rle() and rld()
 for higher-order "values".
 
 See also:
-PDL::VectorValued::Utils::rlevec(), PDL::VectorValued::Utils::rldvec().
+PDL::VectorValued::Utils::vv_rlevec(), PDL::VectorValued::Utils::vv_rldvec().
 
 =cut
 
@@ -128,7 +231,7 @@ PDL::VectorValued::Utils::rlevec(), PDL::VectorValued::Utils::rldvec().
 ## rleND()
 =pod
 
-=head2 rleND
+=head2 vv_rleND
 
 =for sig
 
@@ -138,18 +241,18 @@ PDL::VectorValued::Utils::rlevec(), PDL::VectorValued::Utils::rldvec().
 
 Run-length encode a set of (sorted) n-dimensional values.
 
-Generalization of rle() and rlevec():
+Generalization of rle() and vv_rlevec():
 given set of values $data, generate a vector $counts with the number of occurrences of each element
 (where an "element" is a matrix of dimensions @vdims ocurring as a sequential run over the
 final dimension in $data), and a set of vectors $elts containing the elements which begin a run.
 Really just a wrapper for clump() and rlevec().
 
-See also: PDL::Slices::rle, PDL::Ngrams::VectorValued::Utils::rlevec.
+See also: PDL::Slices::rle, PDL::Ngrams::VectorValued::Utils::vv_rlevec.
 
 =cut
 
-*PDL::rleND = \&rleND;
-sub rleND {
+*PDL::vv_rleND = \&vv_rleND if !defined &PDL::vv_rleND;
+*rleND = sub {
   my $data   = shift;
   my @vdimsN = $data->dims;
 
@@ -158,16 +261,16 @@ sub rleND {
   my $elts   = $#_ >= 1 ? $_[1] : zeroes($data->type, @vdimsN);
 
   ##-- guts: call rlevec()
-  rlevec($data->clump($#vdimsN), $counts, $elts->clump($#vdimsN));
+  vv_rlevec($data->clump($#vdimsN), $counts, $elts->clump($#vdimsN));
 
   return ($counts,$elts);
-}
+} if !defined &rleND;
 
 ##----------------------------------------------------------------------
 ## rldND()
 =pod
 
-=head2 rldND
+=head2 vv_rldND
 
 =for sig
 
@@ -187,8 +290,8 @@ See also: PDL::Slices::rld, PDL::VectorValued::Utils::rldvec
 
 =cut
 
-*PDL::rldND = \&rldND;
-sub rldND {
+*PDL::vv_rldND = \&vv_rldND if !defined &PDL::vv_rldND;
+*rldND = sub {
   my ($counts,$elts) = (shift,shift);
   my @vdimsN        = $elts->dims;
 
@@ -203,10 +306,10 @@ sub rldND {
   }
 
   ##-- guts: call rldvec()
-  rldvec($counts, $elts->clump($#vdimsN), $data->clump($#vdimsN));
+  vv_rldvec($counts, $elts->clump($#vdimsN), $data->clump($#vdimsN));
 
   return $data;
-}
+} if !defined &rldND;
 
 ##======================================================================
 ## pod: Functions: datatype utilities
@@ -237,8 +340,6 @@ sub vv_indx {
   return defined(&PDL::indx) ? PDL::indx(@_) : PDL::long(@_);
 }
 
-1; ##-- make perl happy
-
 
 ##======================================================================
 ## pod: Functions: low-level
@@ -255,6 +356,8 @@ See L<PDL::VectorValued::Utils> for details.
 
 
 
+1; ##-- make perl happy
+
 ##======================================================================
 ## pod: Footer
 =pod
@@ -271,7 +374,7 @@ PDL by Karl Glazebrook, Tuomas J. Lukka, Christian Soeller, and others.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2021, Bryan Jurish.  All rights reserved.
+Copyright (c) 2007-2022, Bryan Jurish.  All rights reserved.
 
 This package is free software.  You may redistribute it
 and/or modify it under the same terms as Perl itself.
